Evapotranspiration
******************

All evapotranspiration methods inherit from ``ETBase``. class.

.. autoclass:: ai4water.et.et_methods.ETBase
        
.. autoclass:: ai4water.et.et_methods.Abtew
        
.. autoclass:: ai4water.et.et_methods.Albrecht

.. autoclass:: ai4water.et.et_methods.BlaneyCriddle

.. autoclass:: ai4water.et.et_methods.BrutsaertStrickler

.. autoclass:: ai4water.et.et_methods.Camargo
